/*  $ID$                                                              */
/**********************************************************************/
/* Copyright (c) 2004 by SAS Institute Inc., Cary, NC USA 27513       */
/* NAME:        'TABLE1'                                              */
/*                                                                    */
/* DATE:        13OCT04                                               */
/* PRODUCT:     HMDA/CRA                                              */
/* PURPOSE:     create lending volume reports                         */
/*                                                                    */
/* USAGE:       %table1;                                              */
/*                                                                    */
/* PARAMETERS:  I|O|U - comments                                      */
/* DOCUMENT:                                                          */
/* TEST PROGRAM:                                                      */
/* NOTES:       called by %petable                                    */
/*                                                                    */
/* END                                                                */
/**********************************************************************/

%macro Table1/ des='create lending vol. reports';                
                
 %local where row;                  
                
 title "Table &table.. Lending Volume %attTitleText";   
 %drillTitles   
                
 %let where = %getSubsetWhere;      
 %let row   = %getRowStub;            
              
             
 %hmdaBankAgg(var=loan_count loan_amount_in_k,          
              sum=HMDA_count HMDA_amount,               
              out=HMDA)             
                
 %craBankAgg(loan_type=loan_type,   
             var=loan_count loan_amount,                
             sum=CRA_count CRA_amount,                  
             out=CRA)               
proc sql noprint;
  select org_class_1, activity_year, aa_group_type, aa_group_description into:title2, :title2year, :aa_group_type, :aa_group_description
  from l_sys.l_assessment_area_group
  where aa_Group_Key = &AA_Group_Key;
  quit;
 run;
                
 data cra;      
  drop CRA_Count CRA_Amount loan_type;                  
  retain CRA_Bus_Count CRA_Bus_Amount CRA_Farm_Count CRA_Farm_Amount CRA_Comm_Count CRA_Comm_Amount;                
  set cra;      
  where loan_type ne ' ';           
  by &row;      
  if loan_Type = '01' then          
  do;  /* Business Loans */         
     CRA_Bus_Count = CRA_Count;     
     CRA_Bus_Amount = CRA_Amount;   
  end; /* Business Loans */         
  else if loan_Type = '02' then     
  do;  /* Business Loans */         
     CRA_Farm_Count = CRA_Count;    
     CRA_Farm_Amount = CRA_Amount;  
  end; /* Business Loans */         
  else if loan_Type = '?' then      
  do;  /* Business Loans */         
     CRA_Comm_Count = CRA_Count;    
     CRA_Comm_Amount = CRA_Amount;  
  end; /* Business Loans */         
  else put _ALL_;                   
  if last.&row; 
  output;       
  CRA_Bus_Count = .;                
  CRA_Bus_Amount = .;               
  CRA_Farm_Count = .;               
  CRA_Farm_Amount = .;              
  CRA_Comm_Count = .;               
  CRA_Comm_Amount = .;              
 run;           
                
 /* get deposit data */             
 data subset;   
  set l_rpts.RptBank_Deposit;    
  where %getSubsetWhere(notUseATT=Y)
        %getOrgClassWhere and ("%assignAA(&aafmt)" ne 'EXCLUDE');               
  AA = %assignAA(&aafmt);           
  label AA = 'Assessment Area';     
 run;           
                
 proc summary data=subset;          
  class &row;   
  var deposit_amount;               
  output out=deposits(drop=_freq_ _type_) sum=;         
 run;           
 
 /* sum up all cd loans (orginated and purchased)  */


 
 data cd_sum; 
    set 
    %do iyear=%substr(&from,6,4) %to %substr(&to,6,4);
        %if %sysfunc(exist(l_&iyear.s.app_cra_agg_comm_dev)) %then
        %do;
          l_&iyear.s.app_cra_agg_comm_dev
        %end;
    %end;  
           end=eof; 
    retain total_cra_comm_amount total_cra_comm_count 0;
    cra_comm_count=loan_orig_count + loan_purchase_count;
    cra_comm_amount=loan_orig_amount + loan_purchase_amount; 
    keep org_class_1 cra_comm_count cra_comm_amount;
    total_cra_comm_amount=total_cra_comm_amount + cra_comm_amount;
    total_cra_comm_count=total_cra_comm_count + cra_comm_count;
    output;
    if eof then
    do; /* add a record for the 'All' (all org_class_1) level */ 
       org_class_1=''; 
       cra_comm_count=total_cra_comm_count;
       cra_comm_amount=total_cra_comm_amount;
       output;
    end;    
run; 
 proc sort data=cd_sum; 
      by org_class_1;
 run;
 
 
data report;   
  if _n_ = 1 and lr then output; /* blank row if no data */                 
  retain loan_tot dep_tot; 
  /*  replace this line with the following conditional merge */
  * merge hmda cra deposits end=lr;
  
  %if %upcase(&row)=ORG_CLASS_1 %then 
  %do; 
     merge hmda cra (drop= cra_comm_count cra_comm_amount) cd_sum deposits end=lr; 
  %end; 
  %else 
  %do; 
     merge hmda cra deposits end=lr; 
  %end; 

  format Total_Pct Deposit_Pct percent9.2               
         HMDA_Count CRA_Bus_Count CRA_Farm_Count CRA_Comm_Count Total_Count comma9.             
         HMDA_Amount CRA_Bus_Amount CRA_Farm_Amount CRA_Comm_Amount Total_Amount dollar12.      
  ;             
  by &row;      
  total_count = sum(HMDA_Count,CRA_Bus_Count,CRA_Farm_Count,CRA_Comm_Count);
  total_amount = sum(HMDA_Amount,CRA_Bus_Amount,CRA_Farm_Amount,CRA_Comm_Amount);               
  if &row = ' ' then                
  do;  /* get the totals for the percentage calcs */    
     loan_tot = total_count;        
     dep_tot = deposit_amount;      
  end; /* get the totals for the percentage calcs */    
  else          
  do;  /* calculate percentages */  
     if total_count then total_pct = total_count/loan_tot;                  
     if deposit_amount then deposit_pct = deposit_amount/dep_tot;           
  end; /* calculate percentages */  
  output;       
 run;           
               
 ods escapechar '~'; 
 proc report data=report nowd split='/' missing out=forCSV(drop=_BREAK_)    
             style(header)={font_size=1 &header_style.};
  columns       
    %if %length(&printable) = 0 %then                   
    %do;  /* add spacer characters for HTML format */   
     ("Lending Volume - Evaluation Period: &eval_period_text"                  
    %end; /* add spacer characters for HTML format */   
    %else       
    %do;  /* add spacer characters for PDF format */    
     ("Lending Volume  Evaluation Period: &eval_period_text"                
    %end; /* add spacer characters for PDF format */    
            (' ' &row total_pct)    
            ("Home Mortage" HMDA_count HMDA_Amount)     
            ("Small Loans/to Business" CRA_Bus_Count CRA_Bus_Amount)        
            ("Small Loans/to Farms" CRA_Farm_Count CRA_Farm_Amount)         
            ("Community Development/Loans" CRA_Comm_Count CRA_Comm_Amount)  
            ("Total Reported Loans" total_count total_amount)               
            (deposit_pct)           
          )     
  ;             
  footnote .h=.9
   %if "&AA_GROUP_KEY" = "0" %then  
            %do;
           .j=left  "All AA for &eval_period_text ";      
        %end;
        %else %if "&aa_group_type" = "S" %then
        %do;
             .j=left  "&title2 - &title2year" ;
        %end;
        %else
        %do;
           .j=left  "&aa_group_description";  
        %end;
   footnote2 .h=.9         
           .j=right "Report Produced %sysfunc(putn(%sysfunc(datetime()),datetime.))";           
  define &row / order format=$rowstub.;                 
  define total_pct / analysis sum '% of Rated/Area Loans/(#)' ;             
  define HMDA_Count / analysis sum "#" ;                
  define HMDA_Amount / analysis sum '$(000)';           
  define CRA_Bus_Count / analysis sum "#";              
  define CRA_Bus_Amount / analysis sum '$(000)';        
  define CRA_Farm_Count / analysis sum "#";             
  define CRA_Farm_Amount / analysis sum '$(000)' ;      
  define CRA_Comm_Count / analysis sum "#" ;            
  define CRA_Comm_Amount / analysis sum '$(000)';       
  define Total_Count / analysis sum "#";                
  define Total_Amount / analysis sum '$(000)' ;         
  define Deposit_Pct / analysis sum "% of/Rated Area/Deposits";             
                
  %if %length(&printable&csv) = 0 and %upcase(&row) ne CENSUS_TRACT %then   
  %do;  /* make the row stub drillable */               
     compute &row;                  
       if &row ne ' ' then call define(_col_,'URL', symget('DRILLURL')||'&'||"&row="||urlencode(trim(&row)));       
     endcomp;   
  %end; /* make the row stub drillable */               
                
                
 quit;          
 run;           
                
%mend Table1;
      
